metadata

Function metadata 

pub fn metadata(path: &Path) -> Result<Metadata>
Counted wrapper around std::fs::metadata.

Errors

Returns an error under the same conditions as std::fs::metadata — most commonly, path does not exist or is not accessible.